Datasets
========

.. automodule:: responsibly.dataset

General Dataset
---------------
.. autoclass:: responsibly.dataset.Dataset
    :members:

Available Datasets
------------------

.. autoclass:: responsibly.dataset.COMPASDataset
    :members:


.. autoclass:: responsibly.dataset.AdultDataset
    :members:


.. autoclass:: responsibly.dataset.GermanDataset
    :members:


FICO Dataset
------------

.. autofunction:: responsibly.dataset.build_FICO_dataset